<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Arqiver::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="144"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
</context>
<context>
    <name>Arqiver::Backend</name>
    <message>
        <location filename="../../backends.cpp" line="634"/>
        <location filename="../../backends.cpp" line="667"/>
        <source>This file is a link but its target does not exist.</source>
        <translation>Questo file è un collegamento a un altro file inesistente.</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1049"/>
        <location filename="../../backends.cpp" line="1080"/>
        <location filename="../../backends.cpp" line="1123"/>
        <source>Could not read archive</source>
        <translation>Impossibile leggere l&apos;archivio</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1083"/>
        <location filename="../../backends.cpp" line="1128"/>
        <source>Archive Loaded</source>
        <translation>Archivio Caricato</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1090"/>
        <location filename="../../backends.cpp" line="1176"/>
        <source>Modification Finished</source>
        <translation>Modifica Terminata</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1111"/>
        <location filename="../../backends.cpp" line="1145"/>
        <source>Extraction Finished</source>
        <translation>Estrazione Terminata</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1114"/>
        <location filename="../../backends.cpp" line="1164"/>
        <source>Extraction Failed</source>
        <translation>Estrazione Non Riuscita</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1273"/>
        <source>%1 is missing from your system.
Please install it for this kind of archive!</source>
        <translation>%1 non è presente nel tuo sistema.
Si prega di installarlo per questo tipo di archivio!</translation>
    </message>
</context>
<context>
    <name>Arqiver::LineEdit</name>
    <message>
        <location filename="../../lineedit.h" line="33"/>
        <source>You could type inside the main view.
Clear text with the Escape key.</source>
        <translation>Puoi digitare all&apos;interno della vista principale.
Cancella il testo con il tasto Esc.</translation>
    </message>
</context>
<context>
    <name>Arqiver::PrefDialog</name>
    <message>
        <location filename="../../pref.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="50"/>
        <source>Start with this size:</source>
        <translation>Inizia con queste dimensioni:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="118"/>
        <source>Show prompt on removing items</source>
        <translation>Mostra prompt alla rimozione di elementi</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="125"/>
        <source>If this is unchecked, only the top level directories will be expanded.</source>
        <translation>Se questa opzione è deselezionata, verranno espanse solo le directory di livello superiore.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="128"/>
        <source>Expand all directories when opening archives</source>
        <translation>Espandi tutte le directory all&apos;apertura degli archivi</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="140"/>
        <location filename="../../pref.ui" line="153"/>
        <source>Leave empty for the default.

Warning: Arqiver will not work if the
binary does not belong to libarchive.</source>
        <translation>Lascia vuoto per l&apos;impostazione predefinita.

Avvertenza: Arqiver non funzionerà se
l&apos;eseguibile non è incluso in libarchive.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="146"/>
        <source>libarchive binary:</source>
        <translation>Eseguibile di libarchive:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="38"/>
        <source>Remember window &amp;size on closing</source>
        <translation>Ricorda le dimen&amp;sioni della finestra alla chiusura</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="93"/>
        <source>Size of view icons:</source>
        <translation>Dimensione delle icone della vista:</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="54"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="208"/>
        <location filename="../../pref.cpp" line="233"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Per rendere effettive le modifiche è necessario riavviare l&apos;applicazione.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="222"/>
        <source>Select libarchive binary</source>
        <translation>Seleziona l&apos;eseguibile di libarchive</translation>
    </message>
</context>
<context>
    <name>Arqiver::mainWin</name>
    <message>
        <location filename="../../mainWin.ui" line="53"/>
        <source>Archive:</source>
        <translation>Archivio:</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="106"/>
        <source>Filter Files...</source>
        <translation>Filtra File...</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="140"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="153"/>
        <source>&amp;View</source>
        <translation>&amp;Visualizza</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="164"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="200"/>
        <source>&amp;Open Archive</source>
        <translation>&amp;Apri Archivio</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="203"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="208"/>
        <source>&amp;New Archive</source>
        <translation>&amp;Nuovo Archivio</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="211"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="216"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="219"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="224"/>
        <source>Add File(s)</source>
        <translation>Aggiungi File</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="229"/>
        <source>Remove File(s)</source>
        <translation>Rimuovi File</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="234"/>
        <source>Extract All</source>
        <translation>Estrai Tutto</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="237"/>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="242"/>
        <source>Add Directory</source>
        <translation>Aggiungi Directory</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="247"/>
        <source>Extract Selection</source>
        <translation>Estrai Selezione</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="252"/>
        <source>Set Password</source>
        <translation>Imposta Password</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="257"/>
        <source>E&amp;xpand</source>
        <translation>&amp;Espandi</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="260"/>
        <source>Ctrl+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="265"/>
        <source>Collap&amp;se</source>
        <translation>&amp;Contrai</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="268"/>
        <source>Ctrl+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="273"/>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="278"/>
        <source>&amp;Copy Current Path</source>
        <translation>&amp;Copia Percorso Corrente</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="283"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferenze</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="288"/>
        <source>Stop &amp;Process</source>
        <translation>Termina &amp;Processo</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="291"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="148"/>
        <source>Root</source>
        <translation>Radice</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="212"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="277"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="277"/>
        <source>MimeType</source>
        <translation>Tipo MIME</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="277"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="488"/>
        <location filename="../../mainWin.cpp" line="759"/>
        <location filename="../../mainWin.cpp" line="802"/>
        <source>Opening Archive...</source>
        <translation>Apertura Archivio...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="695"/>
        <source>Create Archive</source>
        <translation>Crea Archivio</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="721"/>
        <location filename="../../mainWin.cpp" line="911"/>
        <location filename="../../mainWin.cpp" line="1196"/>
        <source>Question</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="722"/>
        <source>The following archive already exists:</source>
        <translation>Il seguente archivio esiste già:</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="724"/>
        <source>Do you want to replace it?
</source>
        <translation>Vuoi sostituirlo?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="751"/>
        <source>Open Archive</source>
        <translation>Apri Archivio</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="817"/>
        <location filename="../../mainWin.cpp" line="824"/>
        <location filename="../../mainWin.cpp" line="860"/>
        <source>Add to Archive</source>
        <translation>Aggiungi ad Archivio</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="855"/>
        <location filename="../../mainWin.cpp" line="886"/>
        <location filename="../../mainWin.cpp" line="1151"/>
        <location filename="../../mainWin.cpp" line="1157"/>
        <source>Adding Items...</source>
        <translation>Aggiungo elementi...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="912"/>
        <source>Do you want to remove the selected item(s)?
</source>
        <translation>Vuoi rimuovere gli elementi selezionati?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="929"/>
        <source>Removing Items...</source>
        <translation>Rimuovo Elementi...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1114"/>
        <location filename="../../mainWin.cpp" line="1129"/>
        <location filename="../../mainWin.cpp" line="1209"/>
        <location filename="../../mainWin.cpp" line="1223"/>
        <source>Extracting...</source>
        <translation>Estrazione...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="969"/>
        <source>Copy Archive Path</source>
        <translation>Copia Percorso Archivio</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="562"/>
        <source>All Types</source>
        <translation>Tutti I Tipi</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="572"/>
        <location filename="../../mainWin.cpp" line="596"/>
        <source>Uncompressed Archive</source>
        <translation>Archivio Non Compresso</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="573"/>
        <location filename="../../mainWin.cpp" line="597"/>
        <source>GZip Compressed Archive</source>
        <translation>Archivio Compresso GZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="575"/>
        <location filename="../../mainWin.cpp" line="599"/>
        <source>BZip2 Compressed Archive</source>
        <translation>Archivio Compresso BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="576"/>
        <location filename="../../mainWin.cpp" line="605"/>
        <source>LMZA Compressed Archive</source>
        <translation>Archivio Compresso LZMA</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="577"/>
        <location filename="../../mainWin.cpp" line="602"/>
        <source>XZ Compressed Archive</source>
        <translation>Archivio Compresso XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="578"/>
        <location filename="../../mainWin.cpp" line="606"/>
        <source>Zstandard Compressed Archive</source>
        <translation>Archivio Compresso Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="579"/>
        <location filename="../../mainWin.cpp" line="608"/>
        <source>CPIO Archive</source>
        <translation>Archivio CPIO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="581"/>
        <location filename="../../mainWin.cpp" line="610"/>
        <source>AR Archive</source>
        <translation>Archivio AR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="583"/>
        <location filename="../../mainWin.cpp" line="612"/>
        <source>Zip Archive</source>
        <translation>Archivio Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="584"/>
        <location filename="../../mainWin.cpp" line="614"/>
        <source>Gzip Archive</source>
        <translation>Archivio Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="585"/>
        <location filename="../../mainWin.cpp" line="613"/>
        <source>7-Zip Archive</source>
        <translation>Archivio 7-Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="600"/>
        <source>READ-ONLY: BZip2 Archive</source>
        <translation>SOLA-LETTURA: Archivio BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="601"/>
        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
        <translation>SOLA-LETTURA: Documento PDF Compresso BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="603"/>
        <source>READ-ONLY: XZ archive</source>
        <translation>SOLA-LETTURA: Archivio XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="604"/>
        <source>READ-ONLY: XZ Compressed PDF Document</source>
        <translation>SOLA-LETTURA: Documento PDF Compresso XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="607"/>
        <source>READ-ONLY: Zstandard archive</source>
        <translation>SOLA-LETTURA: Archivio Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="615"/>
        <source>Gzip Compressed PDF Document</source>
        <translation>Documento PDF Compresso Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="616"/>
        <source>READ-ONLY: Compressed SVG Image</source>
        <translation>SOLA-LETTURA: Immagine SVG Compressa</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="617"/>
        <location filename="../../mainWin.cpp" line="618"/>
        <source>READ-ONLY: ISO Image</source>
        <translation>SOLA-LETTURA: Immagine ISO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="619"/>
        <source>READ-ONLY: XAR Archive</source>
        <translation>SOLA-LETTURA: Archivio XAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="620"/>
        <source>READ-ONLY: Java Archive</source>
        <translation>SOLA-LETTURA: Archivio Java</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="621"/>
        <source>READ-ONLY: Debian Package</source>
        <translation>SOLA-LETTURA: Pacchetto Debian</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="622"/>
        <location filename="../../mainWin.cpp" line="623"/>
        <source>READ-ONLY: RedHat Package</source>
        <translation>SOLA-LETTURA: Pacchetto RedHat</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="624"/>
        <source>READ-ONLY: MS Windows Executable</source>
        <translation>SOLA-LETTURA: Eseguibile MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="625"/>
        <source>READ-ONLY: MS Windows Installer Package</source>
        <translation>SOLA-LETTURA: Pacchetto Installazione MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="626"/>
        <source>READ-ONLY: MS Windows Cabinet Archive</source>
        <translation>SOLA-LETTURA: Archivio Cabinet MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="627"/>
        <source>READ-ONLY: ACE archive</source>
        <translation>SOLA-LETTURA: Archivio ACE</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="628"/>
        <source>READ-ONLY: Android Package</source>
        <translation>SOLA-LETTURA: Pacchetto Android</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="629"/>
        <source>READ-ONLY: RAR Archive</source>
        <translation>SOLA-LETTURA: Archivio RAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="630"/>
        <source>READ-ONLY: AppImage application bundle</source>
        <translation>SOLO IN LETTURA: Bundle Appimage</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="631"/>
        <source>READ-ONLY: VirtualBox Extension Pack</source>
        <translation>SOLA LETTURA: Pacchetto di estensioni VirtualBox</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="640"/>
        <source>All Known Types</source>
        <translation>Tutti I Tipi</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="645"/>
        <source>Show All Files</source>
        <translation>Mostra Tutti I File</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="975"/>
        <source>Open Containing Folder</source>
        <translation>Apri Cartella Contentente</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="296"/>
        <source>View Current Item</source>
        <translation>Mostra Elemento Corrente</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1018"/>
        <location filename="../../mainWin.cpp" line="1026"/>
        <source>Enter Password</source>
        <translation>Inserisci Password</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1030"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1031"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1035"/>
        <source>Encrypt the file list</source>
        <translation>Cripta l&apos;elenco dei file</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1036"/>
        <source>This will take effect after files/folders are added.</source>
        <translation>Ciò avrà effetto dopo l&apos;aggiunta dei file/cartelle.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1107"/>
        <location filename="../../mainWin.cpp" line="1183"/>
        <source>Extract Into Directory</source>
        <translation>Estrai Nella Directory</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1197"/>
        <source>Some files will be overwritten.
Do you want to continue?
</source>
        <translation>Alcuni file verranno sovrascritti.
Vuoi continuare?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1324"/>
        <source>Link To: %1</source>
        <translation>Collegamento A: %1</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1672"/>
        <source>A simple Qt archive manager</source>
        <translation>Un semplice gestore di archivi in Qt</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1673"/>
        <source>based on libarchive, gzip and 7z</source>
        <translation>basato su libarchive, gzip e 7z</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1674"/>
        <source>Author</source>
        <translation>Autore</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1675"/>
        <source>aka.</source>
        <translation>alias</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1676"/>
        <location filename="../../mainWin.cpp" line="1677"/>
        <source>About Arqiver</source>
        <translation>Informazioni su Arqiver</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1676"/>
        <source>Translators</source>
        <translation>Traduttori</translation>
    </message>
</context>
</TS>
